@@ -24,7 +24,7 @@ from PyFstat_example_make_data_for_search_on_1_glitch import (
 
 import pyfstat
 
-label = "PyFstat_example_standard_directed_MCMC_search_on_1_glitch"
+label = "PyFstatExampleStandardDirectedMCMCSearchOn1Glitch"
 logger = pyfstat.set_up_logger(label=label, outdir=outdir)
 
 Nstar = 10000
@@ -47,7 +47,7 @@ nsteps = [500, 2000]
 mcmc = pyfstat.MCMCSearch(
     label=label,
     outdir=outdir,
-    sftfilepattern=os.path.join(outdir, "*1_glitch*sft"),
+    sftfilepattern=os.path.join(outdir, "*1glitch*sft"),
     theta_prior=theta_prior,
     tref=tref,
     minStartTime=tstart,
