@@ -5,13 +5,14 @@ Directed grid search: Quadratic spindown
 Search for CW signal including two spindown parameters
 using a parameter space grid (i.e. no MCMC).
 """
+
 import os
 
 import numpy as np
 
 import pyfstat
 
-label = "PyFstat_example_grid_search_F0F1F2"
+label = "PyFstatExampleGridSearchF0F1F2"
 outdir = os.path.join("PyFstat_example_data", label)
 logger = pyfstat.set_up_logger(label=label, outdir=outdir)
 
