@@ -6,13 +6,14 @@ Directed MCMC search for an isolated CW signal using the
 fully-coherent F-statistic. Prior to the burn-in stage, walkers
 are initialized with a certain scattering factor.
 """
+
 import os
 
 import numpy as np
 
 import pyfstat
 
-label = "PyFstat_example_MCMC_search_using_initialisation"
+label = "PyFstatExampleMCMCSearchUsingInitialisation"
 outdir = os.path.join("PyFstat_example_data", label)
 logger = pyfstat.set_up_logger(label=label, outdir=outdir)
 
@@ -44,7 +45,7 @@ data = pyfstat.Writer(
 )
 data.make_data()
 
-# The predicted twoF, given by lalapps_predictFstat can be accessed by
+# The predicted twoF (expectation over noise realizations) can be accessed by
 twoF = data.predict_fstat()
 logger.info("Predicted twoF value: {}\n".format(twoF))
 
@@ -77,7 +78,7 @@ nsteps = [100, 100]
 mcmc = pyfstat.MCMCSearch(
     label=label,
     outdir=outdir,
-    sftfilepattern=os.path.join(outdir, "*{}*sft".format(label)),
+    sftfilepattern=data.sftfilepath,
     theta_prior=theta_prior,
     tref=mid_time,
     minStartTime=data_parameters["tstart"],
