@@ -5,13 +5,14 @@ MCMC search: Semicoherent F-statistic
 Directed MCMC search for an isolated CW signal using the
 semicoherent F-statistic.
 """
+
 import os
 
 import numpy as np
 
 import pyfstat
 
-label = "PyFstat_example_semi_coherent_MCMC_search"
+label = "PyFstatExampleSemiCoherentMCMCSearch"
 outdir = os.path.join("PyFstat_example_data", label)
 logger = pyfstat.set_up_logger(label=label, outdir=outdir)
 
@@ -43,7 +44,7 @@ data = pyfstat.Writer(
 )
 data.make_data()
 
-# The predicted twoF, given by lalapps_predictFstat can be accessed by
+# The predicted twoF (expectation over noise realizations) can be accessed by
 twoF = data.predict_fstat()
 logger.info("Predicted twoF value: {}\n".format(twoF))
 
@@ -77,7 +78,7 @@ mcmc = pyfstat.MCMCSemiCoherentSearch(
     label=label,
     outdir=outdir,
     nsegs=10,
-    sftfilepattern=os.path.join(outdir, "*{}*sft".format(label)),
+    sftfilepattern=data.sftfilepath,
     theta_prior=theta_prior,
     tref=mid_time,
     minStartTime=data_parameters["tstart"],
