@@ -5,6 +5,7 @@ Randomly sampling parameter space points
 Application of dedicated classes to sample software injection
 parameters according to the specified parameter space priors.
 """
+
 import os
 
 import matplotlib.pyplot as plt
@@ -18,7 +19,7 @@ from pyfstat import (
     set_up_logger,
 )
 
-label = "PyFstat_example_InjectionParametersGenerator"
+label = "PyFstatExampleInjectionParametersGenerator"
 outdir = os.path.join("PyFstat_example_data", label)
 logger = set_up_logger(label=label, outdir=outdir)
 
