@@ -9,6 +9,7 @@ visualizations of the Doppler modulation of a CW signal.
 import os
 
 import matplotlib.pyplot as plt
+import numpy as np
 
 import pyfstat
 
@@ -21,16 +22,33 @@ import pyfstat
 # see https://github.com/matplotlib/matplotlib/issues/21723
 plt.rcParams["axes.grid"] = False
 
-label = "PyFstat_example_spectrogram"
+label = "PyFstatExampleSpectrogramNormPower"
 outdir = os.path.join("PyFstat_example_data", label)
 logger = pyfstat.set_up_logger(label=label, outdir=outdir)
 
 depth = 5
 
+gap_duration = 10 * 86400
+Tsft = 1800
+
+segments = [  # Define the tstart and duration of each segment of data
+    {"tstart": 1000000000, "duration": 120 * 86400},
+    {"tstart": 1000000000 + 120 * 86400 + gap_duration, "duration": 300 * 86400},
+    {"tstart": 1000000000 + 420 * 86400 + 2 * gap_duration, "duration": 120 * 86400},
+]
+
+timestamps = {
+    "H1": np.concatenate(
+        [  # Generate timestamps for each segment and concatenate them
+            segment["tstart"] + Tsft * np.arange(segment["duration"] // Tsft)
+            for segment in segments
+        ]
+    )
+}
+
 data_parameters = {
     "sqrtSX": 1e-23,
-    "tstart": 1000000000,
-    "duration": 2 * 365 * 86400,
+    "timestamps": timestamps,
     "detectors": "H1",
     "Tsft": 1800,
 }
@@ -41,10 +59,10 @@ signal_parameters = {
     "F2": 0,
     "Alpha": 0.0,
     "Delta": 0.5,
-    "tp": data_parameters["tstart"],
+    "tp": segments[0]["tstart"],
     "asini": 25.0,
     "period": 50 * 86400,
-    "tref": data_parameters["tstart"],
+    "tref": segments[0]["tstart"],
     "h0": data_parameters["sqrtSX"] / depth,
     "cosi": 1.0,
 }
@@ -55,24 +73,12 @@ data = pyfstat.BinaryModulatedWriter(
 )
 data.make_data()
 
-logger.info("Loading SFT data and computing normalized power...")
-freqs, times, sft_data = pyfstat.utils.get_sft_as_arrays(data.sftfilepath)
-sft_power = sft_data["H1"].real ** 2 + sft_data["H1"].imag ** 2
-normalized_power = (
-    2 * sft_power / (data_parameters["Tsft"] * data_parameters["sqrtSX"] ** 2)
+ax = pyfstat.utils.plot_spectrogram(
+    sftfilepattern=data.sftfilepath,
+    detector=data_parameters["detectors"],
+    sqrtSX=data_parameters["sqrtSX"],
+    quantity="normpower",
+    savefig=True,
+    outdir=outdir,
+    label=label,
 )
-
-plotfile = os.path.join(outdir, label + ".png")
-logger.info(f"Plotting to file: {plotfile}")
-fig, ax = plt.subplots(figsize=(0.8 * 16, 0.8 * 9))
-ax.set(xlabel="Time [days]", ylabel="Frequency [Hz]", ylim=(99.98, 100.02))
-c = ax.pcolormesh(
-    (times["H1"] - times["H1"][0]) / 86400,
-    freqs,
-    normalized_power,
-    cmap="inferno_r",
-    shading="nearest",
-)
-fig.colorbar(c, label="Normalized Power")
-plt.tight_layout()
-fig.savefig(plotfile)
