@@ -1,9 +1,9 @@
 """ The core tools used in pyfstat """
 
-
 import getpass
 import glob
 import logging
+import math
 import os
 import socket
 from datetime import datetime
@@ -37,6 +37,82 @@ class BaseSearchClass:
     along with full initialization and any other custom methods.
     """
 
+    binary_keys = ["asini", "period", "ecc", "tp", "argp"]
+    """List of extra parameters for sources in binaries."""
+
+    default_search_keys = [
+        "F0",
+        "F1",
+        "F2",
+        "Alpha",
+        "Delta",
+    ]
+    """Default order of the traditionally supported search parameter names.
+
+    FIXME: these are only used as fallbacks for the deprecated style
+    of passing keys one by one;
+    not needed when using the new parameters dictionary.
+    """
+
+    tex_labels = {
+        # standard Doppler parameters
+        "F0": r"$f$",
+        "F1": r"$\dot{f}$",
+        "F2": r"$\ddot{f}$",
+        "F3": r"$\dddot{f}$",
+        "Alpha": r"$\alpha$",
+        "Delta": r"$\delta$",
+        # binary parameters
+        "asini": r"$\mathrm{asin}\,i$",
+        "period": r"$P$",
+        "ecc": r"$\mathrm{ecc}$",
+        "tp": r"$t_p$",
+        "argp": r"$\mathrm{argp}$",
+        # transient parameters
+        "transient_tstart": r"$t_\mathrm{start}$",
+        "transient_duration": r"$\Delta T$",
+        # glitch parameters
+        "delta_F0": r"$\delta f$",
+        "delta_F1": r"$\delta \dot{f}$",
+        "tglitch": r"$t_\mathrm{glitch}$",
+        # detection statistics
+        "twoF": r"$\widetilde{2\mathcal{F}}$",
+        "maxTwoF": r"$\max\widetilde{2\mathcal{F}}$",
+        "log10BSGL": r"$\log_{10}\mathcal{B}_{\mathrm{SGL}}$",
+        "lnBtSG": r"$\ln\mathcal{B}_{\mathrm{tS/G}}$",
+    }
+    """Formatted labels used for plot annotations."""
+
+    unit_dictionary = dict(
+        # standard Doppler parameters
+        F0=r"Hz",
+        F1=r"Hz/s",
+        F2=r"Hz/s$^2$",
+        F3=r"Hz/s$^3$",
+        Alpha=r"rad",
+        Delta=r"rad",
+        # binary parameters
+        asini="",
+        period=r"s",
+        ecc="",
+        tp=r"s",
+        argp="",
+        # transient parameters
+        transient_tstart=r"s",
+        transient_duration=r"s",
+        # glitch parameters
+        delta_F0=r"Hz",
+        delta_F1=r"Hz/s",
+        tglitch=r"s",
+    )
+    """Units for standard parameters."""
+
+    fmt_detstat = "%.9g"
+    """Standard output precision for detection statistics."""
+
+    fmt_doppler = "%.16g"
+    """Standard output precision for Doppler (frequency evolution) parameters."""
+
     def __new__(cls, *args, **kwargs):
         logger.info(f"Creating {cls.__name__} object...")
         instance = super().__new__(cls)
@@ -49,9 +125,14 @@ class BaseSearchClass:
         matches = [item for sublist in matches for item in sublist]
         if len(matches) > 0:
             return matches
-        else:
+        else:  # pragma: no cover
             raise IOError("No sfts found matching {}".format(self.sftfilepattern))
 
+    def tex_label0(self, key):
+        """Formatted labels used for annotating central values in plots."""
+        label = self.tex_labels[key].strip("$")
+        return f"${label} - {label}_0$"
+
     def set_ephemeris_files(self, earth_ephem=None, sun_ephem=None):
         """Set the ephemeris files to use for the Earth and Sun.
 
@@ -92,7 +173,7 @@ class BaseSearchClass:
         pretty_init_parameters = (
             ["{"]
             + [pretty_init_parameters[0].replace("{", " ")]
-            + pretty_init_parameters[1:-2]
+            + pretty_init_parameters[1:-1]
             + [pretty_init_parameters[-1].rstrip("}")]
             + ["}"]
         )
@@ -161,46 +242,11 @@ class BaseSearchClass:
     def translate_keys_to_lal(dictionary):
         """Convert input keys into lalpulsar convention.
 
-        In PyFstat's convention, input keys (search parameter names)
-        are F0, F1, F2, ...,
-        while lalpulsar functions prefer to use Freq, f1dot, f2dot, ....
-
-        Since lalpulsar keys are only used internally to call lalpulsar routines,
-        this function is provided so the keys can be translated on the fly.
-
-        Parameters
-        ----------
-        dictionary: dict
-            Dictionary to translate. A copy will be made (and returned)
-            before translation takes place.
-
-        Returns
-        -------
-        translated_dict: dict
-            Copy of "dictionary" with new keys according to lalpulsar convention.
+        This is a wrapper for `utils.translate_keys_to_lal`,
+        see there for details.
         """
 
-        translation = {
-            "F0": "Freq",
-            "F1": "f1dot",
-            "F2": "f2dot",
-            "phi": "phi0",
-            "tref": "refTime",
-            "asini": "orbitasini",
-            "period": "orbitPeriod",
-            "tp": "orbitTp",
-            "argp": "orbitArgp",
-            "ecc": "orbitEcc",
-            "transient_tstart": "transient-t0Epoch",
-            "transient_duration": "transient-tau",
-        }
-
-        keys_to_translate = [key for key in dictionary.keys() if key in translation]
-
-        translated_dict = dictionary.copy()
-        for key in keys_to_translate:
-            translated_dict[translation[key]] = translated_dict.pop(key)
-        return translated_dict
+        return utils.translate_keys_to_lal(dictionary)
 
 
 class ComputeFstat(BaseSearchClass):
@@ -285,7 +331,7 @@ class ComputeFstat(BaseSearchClass):
             GPS seconds of the reference time.
         sftfilepattern : str
             Pattern to match SFTs using wildcards (`*?`) and ranges [0-9];
-            mutiple patterns can be given separated by colons.
+            multiple patterns can be given separated by colons.
         minStartTime, maxStartTime : int
             Only use SFTs with timestamps starting from within this range,
             following the XLALCWGPSinRange convention:
@@ -389,7 +435,7 @@ class ComputeFstat(BaseSearchClass):
            Running-Median window size for F-statistic noise normalization
            (number of SFT bins).
         tCWFstatMapVersion: str
-            Choose between implementations of the transient F-statistic funcionality:
+            Choose between implementations of the transient F-statistic functionality:
             standard `lal` implementation,
             `pycuda` for GPU version,
             and some others only for devel/debug.
@@ -520,6 +566,8 @@ class ComputeFstat(BaseSearchClass):
             " with constraints {}.".format(self.sftfilepattern, ", ".join(constr_str))
         )
         self.SFTCatalog = lalpulsar.SFTdataFind(self.sftfilepattern, constraints)
+        if self.SFTCatalog.length == 0:
+            raise IOError("No SFTs found.")
         Tsft_from_catalog = int(1.0 / self.SFTCatalog.data[0].header.deltaF)
         if Tsft_from_catalog != self.Tsft:
             logger.info(
@@ -550,7 +598,7 @@ class ComputeFstat(BaseSearchClass):
             # maxStartTime must always be > last actual SFT timestamp
             self.maxStartTime = int(SFT_timestamps[-1]) + self.Tsft
 
-        self.detector_names = list(set([d.header.name for d in self.SFTCatalog.data]))
+        self.detector_names = np.unique([d.header.name for d in self.SFTCatalog.data])
         self.numDetectors = len(self.detector_names)
         if self.numDetectors == 0:
             raise ValueError("No data loaded.")
@@ -560,6 +608,27 @@ class ComputeFstat(BaseSearchClass):
             )
         )
 
+    def _parse_Fk_key(self, key):
+        try:
+            k = int(key[1:])
+        except ValueError:  # pragma: no cover
+            raise ValueError(
+                f"Unknown parameter {key} in input dictionary, it looks like a 'Fk'-style spindown term but cannot convert the part after the 'F' to an integer."
+            )
+        if k >= lalpulsar.PULSAR_MAX_SPINS:  # pragma: no cover
+            raise ValueError(
+                f"Input parameter {key} exceeds lalpulsar.PULSAR_MAX_SPINS={lalpulsar.PULSAR_MAX_SPINS}."
+            )
+        return k
+
+    def _set_fkdot_from_params_dict(self, params_dict):
+        fkdot = np.zeros(lalpulsar.PULSAR_MAX_SPINS)
+        for key in params_dict:
+            if key.startswith("F"):
+                k = self._parse_Fk_key(key)
+                fkdot[k] = params_dict[key]
+        return fkdot
+
     def init_computefstatistic(self):
         """Initialization step for the F-stastic computation internals.
 
@@ -617,7 +686,7 @@ class ComputeFstat(BaseSearchClass):
         if self.allowedMismatchFromSFTLength:
             FstatOAs.allowedMismatchFromSFTLength = self.allowedMismatchFromSFTLength
 
-        if hasattr(self, "injectSources") and type(self.injectSources) == dict:
+        if hasattr(self, "injectSources") and isinstance(self.injectSources, dict):
             logger.info("Injecting source with params: {}".format(self.injectSources))
             PPV = lalpulsar.CreatePulsarParamsVector(1)
             PP = PPV.data[0]
@@ -638,14 +707,12 @@ class ComputeFstat(BaseSearchClass):
             if "fkdot" in self.injectSources:
                 PP.Doppler.fkdot = np.array(self.injectSources["fkdot"])
             else:
-                PP.Doppler.fkdot = np.zeros(lalpulsar.PULSAR_MAX_SPINS)
-                for i, key in enumerate(["F0", "F1", "F2"]):
-                    PP.Doppler.fkdot[i] = self.injectSources[key]
+                PP.Doppler.fkdot = self._set_fkdot_from_params_dict(self.injectSources)
             PP.Doppler.refTime = self.tref
             if "t0" not in self.injectSources:
                 PP.Transient.type = lalpulsar.TRANSIENT_NONE
             FstatOAs.injectSources = PPV
-        elif hasattr(self, "injectSources") and type(self.injectSources) == str:
+        elif hasattr(self, "injectSources") and isinstance(self.injectSources, str):
             logger.info(
                 "Injecting source from param file: {}".format(self.injectSources)
             )
@@ -663,9 +730,9 @@ class ComputeFstat(BaseSearchClass):
                 )
             FstatOAs.injectSqrtSX = lalpulsar.MultiNoiseFloor()
             FstatOAs.injectSqrtSX.length = len(self.injectSqrtSX)
-            FstatOAs.injectSqrtSX.sqrtSn[
-                : FstatOAs.injectSqrtSX.length
-            ] = self.injectSqrtSX
+            FstatOAs.injectSqrtSX.sqrtSn[: FstatOAs.injectSqrtSX.length] = (
+                self.injectSqrtSX
+            )
         else:
             FstatOAs.injectSqrtSX = lalpulsar.FstatOptionalArgsDefaults.injectSqrtSX
         # Here we are treating 0 and None as equivalent
@@ -690,8 +757,6 @@ class ComputeFstat(BaseSearchClass):
         logger.info("Initialising PulsarDoplerParams")
         PulsarDopplerParams = lalpulsar.PulsarDopplerParams()
         PulsarDopplerParams.refTime = self.tref
-        PulsarDopplerParams.Alpha = 1
-        PulsarDopplerParams.Delta = 1
         PulsarDopplerParams.fkdot = np.zeros(lalpulsar.PULSAR_MAX_SPINS)
         self.PulsarDopplerParams = PulsarDopplerParams
 
@@ -735,7 +800,9 @@ class ComputeFstat(BaseSearchClass):
             )
 
         if self.transientWindowType:
-            logger.info("Initialising transient parameters")
+            logger.info(
+                f"Initialising transient parameters for window type '{self.transientWindowType}'"
+            )
             self.maxTwoF = 0
             if getattr(self, "BtSG", False):
                 self.lnBtSG = np.nan
@@ -943,8 +1010,8 @@ class ComputeFstat(BaseSearchClass):
         # frequency and spindowns
         searchRegion.fkdot = np.zeros(lalpulsar.PULSAR_MAX_SPINS)
         searchRegion.fkdotBand = np.zeros(lalpulsar.PULSAR_MAX_SPINS)
-        for k in range(3):
-            Fk = "F{:d}".format(k)
+        for k in range(lalpulsar.PULSAR_MAX_SPINS):
+            Fk = f"F{k}"
             if Fk in range_keys:
                 searchRegion.fkdot[k] = self.search_ranges[Fk][0]
                 searchRegion.fkdotBand[k] = (
@@ -968,9 +1035,9 @@ class ComputeFstat(BaseSearchClass):
             else 0.001  # fallback, irrelevant for band estimate but must be > 0
         )
         scanInit.stepSizes.fkdot = np.zeros(lalpulsar.PULSAR_MAX_SPINS)
-        for k in range(3):
+        for k in range(lalpulsar.PULSAR_MAX_SPINS):
+            Fk = f"F{k}"
             if Fk in range_keys:
-                Fk = "F{:d}".format(k)
                 scanInit.stepSizes.fkdot[k] = (
                     self.search_ranges[Fk][-1]
                     if len(self.search_ranges[Fk]) == 3
@@ -1007,12 +1074,8 @@ class ComputeFstat(BaseSearchClass):
             tref=self.tref,
             tstart=self.minStartTime,
             tend=self.maxStartTime,
-            F0=spinRangeRef.fkdot[0],
-            F1=spinRangeRef.fkdot[1],
-            F2=spinRangeRef.fkdot[2],
-            F0band=spinRangeRef.fkdotBand[0],
-            F1band=spinRangeRef.fkdotBand[1],
-            F2band=spinRangeRef.fkdotBand[2],
+            fkdot=spinRangeRef.fkdot,
+            fkdotBand=spinRangeRef.fkdotBand,
             maxOrbitAsini=maxOrbitAsini,
             minOrbitPeriod=minOrbitPeriod,
             maxOrbitEcc=maxOrbitEcc,
@@ -1020,16 +1083,17 @@ class ComputeFstat(BaseSearchClass):
 
     def get_fullycoherent_detstat(
         self,
-        F0,
-        F1,
-        F2,
-        Alpha,
-        Delta,
+        F0=None,
+        F1=None,
+        F2=None,
+        Alpha=None,
+        Delta=None,
         asini=None,
         period=None,
         ecc=None,
         tp=None,
         argp=None,
+        params=None,
         tstart=None,
         tend=None,
     ):
@@ -1068,12 +1132,26 @@ class ComputeFstat(BaseSearchClass):
         The full transient-F-stat map is also computed here,
         but stored in `self.FstatMap`, not returned.
 
+        NOTE: the old way of calling this with explicit [F0,F1,F2,Alpha,Delta,...]
+        parameters is DEPRECATED and may be removed in future versions.
+        Currently, this method can be either called with
+
+        * a complete set of `(F0, F1, F2, Alpha, Delta)`
+          (plus optional binary parameters),
+
+        * OR a `params` dictionary;
+
+        and only the latter version will be supported going forward.
+
         Parameters
         ----------
         F0, F1, F2, Alpha, Delta: float
-            Parameters at which to compute the statistic.
+            DEPRECATED: Parameters at which to compute the statistic.
         asini, period, ecc, tp, argp: float, optional
-            Optional: Binary parameters at which to compute the statistic.
+            DEPRECATED: Optional: Binary parameters at which to compute the statistic.
+        params: dict
+            A dictionary defining a parameter space point.
+            See get_fullycoherent_twoF() for more information.
         tstart, tend: int or None
             GPS times to restrict the range of data used.
             If None: falls back to self.minStartTime and self.maxStartTime.
@@ -1087,11 +1165,21 @@ class ComputeFstat(BaseSearchClass):
             at the input parameter values.
         """
         self.get_fullycoherent_twoF(
-            F0, F1, F2, Alpha, Delta, asini, period, ecc, tp, argp
+            F0=F0,
+            F1=F1,
+            F2=F2,
+            Alpha=Alpha,
+            Delta=Delta,
+            asini=asini,
+            period=period,
+            ecc=ecc,
+            tp=tp,
+            argp=argp,
+            params=params,
         )
+        if self.singleFstats:
+            self.get_fullycoherent_single_IFO_twoFs()
         if not self.transientWindowType:
-            if self.singleFstats:
-                self.get_fullycoherent_single_IFO_twoFs()
             if not self.BSGL:
                 return self.twoF
             self.get_fullycoherent_log10BSGL()
@@ -1101,18 +1189,97 @@ class ComputeFstat(BaseSearchClass):
             tend=tend,
         )
 
-    def get_fullycoherent_twoF(
+    def _set_PulsarDopplerParams(
         self,
-        F0,
-        F1,
-        F2,
-        Alpha,
-        Delta,
+        params=None,
+        F0=None,
+        F1=None,
+        F2=None,
+        Alpha=None,
+        Delta=None,
         asini=None,
         period=None,
         ecc=None,
         tp=None,
         argp=None,
+    ):
+        """Helper function to set a PulsarDoplerParams struct from user inputs.
+
+        No return value, struct is set as an attribute of the class instance.
+
+        FIXME: this can be simplified a lot when removing the deprecated
+        way of calling with individual parameters instead of a dict!
+
+        Parameters
+        ----------
+        params: dict, optional
+            A dictionary defining a parameter space point.
+            See get_fullycoherent_twoF() for more information.
+        F0, F1, F2, Alpha, Delta: float, optional
+            DEPRECATED: Parameters at which to compute the statistic.
+        asini, period, ecc, tp, argp: float, optional
+            DEPRECATED: Optional: Binary parameters at which to compute the statistic
+
+        """
+        base_params_oldstyle = {
+            "F0": F0,
+            "F1": F1,
+            "F2": F2,
+            "Alpha": Alpha,
+            "Delta": Delta,
+        }
+        if params is not None:
+            required_keys = ["F0", "Alpha", "Delta"]
+            parkeys = list(params.keys())
+            keysetdiff = np.setdiff1d(required_keys, parkeys)
+            if len(keysetdiff) > 0:  # pragma: no cover
+                raise ValueError(
+                    f"Required keys not found in params.keys(): {keysetdiff}"
+                )
+            # all supported parameters are either required, binary, or of "Fk" type
+            keysetdiff = np.setdiff1d(parkeys, required_keys + self.binary_keys)
+            if not np.all(
+                [key.startswith("F") for key in keysetdiff]
+            ):  # pragma: no cover
+                raise ValueError(
+                    f"Unknown parameters in input dictionary: {[key for key in keysetdiff if not key.startswith('F')]}"
+                )
+        elif sum([val is not None for val in base_params_oldstyle.values()]) == 5:
+            params = {key: float(val) for key, val in base_params_oldstyle.items()}
+            parkeys = list(params.keys())
+            if self.binary:
+                for key in self.binary_keys:
+                    bpar = eval(key)
+                    if bpar is None:  # pragma: no cover
+                        raise ValueError(f"We got self.binary but {key}=None.")
+                    params[key] = float(bpar)
+                parkeys += self.binary_keys
+        else:  # pragma: no cover
+            raise ValueError(
+                "Need either a 'params' dictionary"
+                f" or a full set of {list(base_params_oldstyle.keys())} (DEPRECATED)"
+                f" plus optional binary parameters (also DEPRECATED)."
+            )
+
+        self.PulsarDopplerParams.fkdot = self._set_fkdot_from_params_dict(params)
+        self.PulsarDopplerParams.Alpha = float(params["Alpha"])
+        self.PulsarDopplerParams.Delta = float(params["Delta"])
+        for key in np.intersect1d(self.binary_keys, parkeys, assume_unique=True):
+            setattr(self.PulsarDopplerParams, key, float(params[key]))
+
+    def get_fullycoherent_twoF(
+        self,
+        F0=None,
+        F1=None,
+        F2=None,
+        Alpha=None,
+        Delta=None,
+        asini=None,
+        period=None,
+        ecc=None,
+        tp=None,
+        argp=None,
+        params=None,
     ):
         """Computes the fully-coherent 2F statistic at a single point.
 
@@ -1121,14 +1288,32 @@ class ComputeFstat(BaseSearchClass):
         If you want to restrict the range of data used for a single 2F computation,
         you need to set a `self.transientWindowType` and then call
         `self.get_fullycoherent_detstat()` with `tstart` and `tend` options
-        instead of this funcion.
+        instead of this function.
+
+        NOTE the old way of calling this with explicit (F0,F1,F2,Alpha,Delta,...)
+        parameters is DEPRECATED and may be removed in future versions.
+        Currently, this method can be either called with
+
+        * a complete set of `(F0, F1, F2, Alpha, Delta)`
+          (plus optional binary parameters),
+
+        * OR a `params` dictionary;
+
+        and only the latter version will be supported going forward.
 
         Parameters
         ----------
         F0, F1, F2, Alpha, Delta: float
-            Parameters at which to compute the statistic.
+            DEPRECATED: Parameters at which to compute the statistic.
         asini, period, ecc, tp, argp: float, optional
-            Optional: Binary parameters at which to compute the statistic.
+            DEPRECATED: Optional: Binary parameters at which to compute the statistic.
+        params: dict
+            A dictionary defining a parameter space point,
+            with `["F0","Alpha","Delta"]` required as a minimum set of keys.
+            Also supported:
+            Fk with `1<k<lalpulsar.PULSAR_MAX_SPINS`
+            and binary parameters `asini, period, ecc, tp, argp`
+            (basically anything that fits within a `PulsarDopplerParams` struct).
 
         Returns
         -------
@@ -1137,16 +1322,20 @@ class ComputeFstat(BaseSearchClass):
             at the input parameter values.
             Also stored as `self.twoF`.
         """
-        self.PulsarDopplerParams.fkdot = np.zeros(lalpulsar.PULSAR_MAX_SPINS)
-        self.PulsarDopplerParams.fkdot[:3] = [F0, F1, F2]
-        self.PulsarDopplerParams.Alpha = float(Alpha)
-        self.PulsarDopplerParams.Delta = float(Delta)
-        if self.binary:
-            self.PulsarDopplerParams.asini = float(asini)
-            self.PulsarDopplerParams.period = float(period)
-            self.PulsarDopplerParams.ecc = float(ecc)
-            self.PulsarDopplerParams.tp = float(tp)
-            self.PulsarDopplerParams.argp = float(argp)
+
+        self._set_PulsarDopplerParams(
+            params,
+            F0=F0,
+            F1=F1,
+            F2=F2,
+            Alpha=Alpha,
+            Delta=Delta,
+            asini=asini,
+            period=period,
+            ecc=ecc,
+            tp=tp,
+            argp=argp,
+        )
 
         lalpulsar.ComputeFstat(
             Fstats=self.FstatResults,
@@ -1155,6 +1344,7 @@ class ComputeFstat(BaseSearchClass):
             numFreqBins=1,
             whatToCompute=self.whatToCompute,
         )
+
         # We operate on a single frequency bin, so we grab the 0 component
         # of what is internally a twoF array.
         self.twoF = float(self.FstatResults.twoF[0])
@@ -1364,16 +1554,17 @@ class ComputeFstat(BaseSearchClass):
 
     def calculate_twoF_cumulative(
         self,
-        F0,
-        F1,
-        F2,
-        Alpha,
-        Delta,
+        F0=None,
+        F1=None,
+        F2=None,
+        Alpha=None,
+        Delta=None,
         asini=None,
         period=None,
         ecc=None,
         tp=None,
         argp=None,
+        params=None,
         tstart=None,
         tend=None,
         transient_tstart=None,
@@ -1390,9 +1581,12 @@ class ComputeFstat(BaseSearchClass):
         Parameters
         ----------
         F0, F1, F2, Alpha, Delta: float
-            Parameters at which to compute the cumulative twoF.
+            DEPRECATED: Parameters at which to compute the cumulative twoF.
         asini, period, ecc, tp, argp: float, optional
-            Optional: Binary parameters at which to compute the cumulative 2F.
+            DEPRECATED: Optional: Binary parameters at which to compute the cumulative 2F.
+        params: dict
+            A dictionary defining a parameter space point.
+            See get_fullycoherent_twoF() for more information.
         tstart, tend: int or None
             GPS times to restrict the range of data used.
             If None: falls back to self.minStartTime and self.maxStartTime;.
@@ -1435,6 +1629,7 @@ class ComputeFstat(BaseSearchClass):
                 ecc=ecc,
                 tp=tp,
                 argp=argp,
+                params=params,
             )
             for duration in cumulative_durations
         ]
@@ -1575,9 +1770,11 @@ class ComputeFstat(BaseSearchClass):
         # Set up plot-related objects
         axis_kwargs = {
             "xlabel": f"Days from $t_\\mathrm{{start}}={actual_tstart_CFS:.0f}$",
-            "ylabel": "$\\log_{10}(\\mathrm{BSGL})_{\\mathrm{cumulative}}$"
-            if self.BSGL
-            else "$\\widetilde{2\\mathcal{F}}_{\\mathrm{cumulative}}$",
+            "ylabel": (
+                "$\\log_{10}(\\mathrm{BSGL})_{\\mathrm{cumulative}}$"
+                if self.BSGL
+                else "$\\widetilde{2\\mathcal{F}}_{\\mathrm{cumulative}}$"
+            ),
             "xlim": (0, taus_CFS_days[-1]),
         }
         plot_label = (
@@ -1672,11 +1869,11 @@ class ComputeFstat(BaseSearchClass):
             dopplerName = lalpulsar.PulsarDopplerParams2String(self.PulsarDopplerParams)
             # fnameAtoms = os.path.join(self.outdir,'Fstatatoms_%s.dat' % dopplerName)
             fnameAtoms = f"{fnamebase}_Fstatatoms_{dopplerName}.dat"
-            fo = lal.FileOpen(fnameAtoms, "w")
+            fpout = lal.FileOpen(fnameAtoms, "w")
             for hline in self.output_file_header:
-                lal.FilePuts(f"{comments} {hline}\n", fo)
-            lalpulsar.write_MultiFstatAtoms_to_fp(fo, multiFatoms[0])
-            del fo  # instead of lal.FileClose() which is not SWIG-exported
+                lal.FilePuts(f"{comments} {hline}\n", fpout)
+            lalpulsar.write_MultiFstatAtoms_to_fp(fpout, multiFatoms[0])
+            del fpout  # instead of lal.FileClose() which is not SWIG-exported
         else:
             raise RuntimeError(
                 "Cannot print atoms vector to file: no FstatResults.multiFatoms, or it is None!"
@@ -1846,16 +2043,17 @@ class SemiCoherentSearch(ComputeFstat):
 
     def get_semicoherent_det_stat(
         self,
-        F0,
-        F1,
-        F2,
-        Alpha,
-        Delta,
+        F0=None,
+        F1=None,
+        F2=None,
+        Alpha=None,
+        Delta=None,
         asini=None,
         period=None,
         ecc=None,
         tp=None,
         argp=None,
+        params=None,
         record_segments=False,
     ):
         """Computes the detection statistic (twoF or log10BSGL) semi-coherently at a single point.
@@ -1867,9 +2065,12 @@ class SemiCoherentSearch(ComputeFstat):
         Parameters
         ----------
         F0, F1, F2, Alpha, Delta: float
-            Parameters at which to compute the statistic.
+            DEPRECATED: Parameters at which to compute the statistic.
         asini, period, ecc, tp, argp: float, optional
-            Optional: Binary parameters at which to compute the statistic.
+            DEPRECATED:Optional: Binary parameters at which to compute the statistic.
+        params: dict
+            A dictionary defining a parameter space point.
+            See get_fullycoherent_twoF() for more information.
         record_segments: boolean
             If True, store the per-segment F-stat values as `self.twoF_per_segment`
             and (if `self.singleFstats`) the per-detector per-segment F-stats
@@ -1884,7 +2085,18 @@ class SemiCoherentSearch(ComputeFstat):
         """
 
         self.get_semicoherent_twoF(
-            F0, F1, F2, Alpha, Delta, asini, period, ecc, tp, argp, record_segments
+            F0=F0,
+            F1=F1,
+            F2=F2,
+            Alpha=Alpha,
+            Delta=Delta,
+            asini=asini,
+            period=period,
+            ecc=ecc,
+            tp=tp,
+            argp=argp,
+            params=params,
+            record_segments=record_segments,
         )
 
         if self.singleFstats:
@@ -1896,16 +2108,17 @@ class SemiCoherentSearch(ComputeFstat):
 
     def get_semicoherent_twoF(
         self,
-        F0,
-        F1,
-        F2,
-        Alpha,
-        Delta,
+        F0=None,
+        F1=None,
+        F2=None,
+        Alpha=None,
+        Delta=None,
         asini=None,
         period=None,
         ecc=None,
         tp=None,
         argp=None,
+        params=None,
         record_segments=False,
     ):
         """Computes the semi-coherent twoF statistic at a single point.
@@ -1913,9 +2126,12 @@ class SemiCoherentSearch(ComputeFstat):
         Parameters
         ----------
         F0, F1, F2, Alpha, Delta: float
-            Parameters at which to compute the statistic.
+            DEPRECATED: Parameters at which to compute the statistic.
         asini, period, ecc, tp, argp: float, optional
-            Optional: Binary parameters at which to compute the statistic.
+            DEPRECATED: Optional: Binary parameters at which to compute the statistic.
+        params: dict
+            A dictionary defining a parameter space point.
+            See get_fullycoherent_twoF() for more information.
         record_segments: boolean
             If True, store the per-segment F-stat values as `self.twoF_per_segment`.
 
@@ -1927,16 +2143,19 @@ class SemiCoherentSearch(ComputeFstat):
             Also stored as `self.twoF`.
         """
 
-        self.PulsarDopplerParams.fkdot = np.zeros(lalpulsar.PULSAR_MAX_SPINS)
-        self.PulsarDopplerParams.fkdot[:3] = [F0, F1, F2]
-        self.PulsarDopplerParams.Alpha = float(Alpha)
-        self.PulsarDopplerParams.Delta = float(Delta)
-        if self.binary:
-            self.PulsarDopplerParams.asini = float(asini)
-            self.PulsarDopplerParams.period = float(period)
-            self.PulsarDopplerParams.ecc = float(ecc)
-            self.PulsarDopplerParams.tp = float(tp)
-            self.PulsarDopplerParams.argp = float(argp)
+        self._set_PulsarDopplerParams(
+            params,
+            F0=F0,
+            F1=F1,
+            F2=F2,
+            Alpha=Alpha,
+            Delta=Delta,
+            asini=asini,
+            period=period,
+            ecc=ecc,
+            tp=tp,
+            argp=argp,
+        )
 
         lalpulsar.ComputeFstat(
             Fstats=self.FstatResults,
@@ -2005,9 +2224,9 @@ class SemiCoherentSearch(ComputeFstat):
                 twoFX_per_segment = np.nan_to_num(twoFX_per_segment, nan=0.0)
                 self.twoFX[X] = twoFX_per_segment.sum()
             if record_segments:
-                self.twoFX_per_segment[
-                    : self.FstatResults.numDetectors, :
-                ] = twoFX_per_segment
+                self.twoFX_per_segment[: self.FstatResults.numDetectors, :] = (
+                    twoFX_per_segment
+                )
         return self.twoFX
 
     def get_semicoherent_log10BSGL(self):
@@ -2064,7 +2283,7 @@ class SearchForSignalWithJumps(BaseSearchClass):
 
         """
         m = np.zeros((n, n))
-        factorial = np.math.factorial
+        factorial = math.factorial
         for i in range(n):
             for j in range(n):
                 if i == j:
@@ -2230,6 +2449,9 @@ class SemiCoherentGlitchSearch(SearchForSignalWithJumps, ComputeFstat):
     def get_semicoherent_nglitch_twoF(self, F0, F1, F2, Alpha, Delta, *args):
         """Returns the semi-coherent glitch summed twoF.
 
+        FIXME: not yet ported to the new parameter dictionary style
+        of other detection statistics methods.
+
         Parameters
         ----------
         F0, F1, F2, Alpha, Delta: float
@@ -2262,16 +2484,16 @@ class SemiCoherentGlitchSearch(SearchForSignalWithJumps, ComputeFstat):
 
         twoFSum = 0
         for i, theta_i_at_tref in enumerate(thetas):
-            ts, te = tboundaries[i], tboundaries[i + 1]
-            if te - ts > 1800:
+            tstart, tend = tboundaries[i], tboundaries[i + 1]
+            if tend - tstart > 1800:
                 twoFVal = self.get_fullycoherent_detstat(
                     F0=theta_i_at_tref[1],
                     F1=theta_i_at_tref[2],
                     F2=theta_i_at_tref[3],
                     Alpha=Alpha,
                     Delta=Delta,
-                    tstart=ts,
-                    tend=te,
+                    tstart=tstart,
+                    tend=tend,
                 )
                 twoFSum += twoFVal
 
