@@ -1,15 +1,15 @@
 """PyFstat search classes using grid-based methods."""
 
-
 import itertools
 import logging
 import os
 import re
-from collections import OrderedDict
 
+import lalpulsar
 import matplotlib
 import matplotlib.pyplot as plt
 import numpy as np
+import pandas as pd
 from tqdm import tqdm
 
 import pyfstat.utils as utils
@@ -44,31 +44,6 @@ class GridSearch(BaseSearchClass):
     only the additional ones are documented here:
     """
 
-    tex_labels = {
-        "F0": r"$f$",
-        "F1": r"$\dot{f}$",
-        "F2": r"$\ddot{f}$",
-        "Alpha": r"$\alpha$",
-        "Delta": r"$\delta$",
-        "twoF": r"$\widetilde{2\mathcal{F}}$",
-        "maxTwoF": r"$\max\widetilde{2\mathcal{F}}$",
-        "log10BSGL": r"$\log_{10}\mathcal{B}_{\mathrm{S/GL}}$",
-        "lnBtSG": r"$\ln\mathcal{B}_{\mathrm{tS/G}}$",
-    }
-    """Formatted labels used for plot annotations."""
-
-    tex_labels0 = {
-        "F0": r"$-f_0$",
-        "F1": r"$-\dot{f}_0$",
-        "F2": r"$-\ddot{f}_0$",
-        "Alpha": r"$-\alpha_0$",
-        "Delta": r"$-\delta_0$",
-    }
-    """Formatted labels used for annotating central values in plots."""
-
-    fmt_detstat = "%.9g"
-    """Standard output precision for detection statistics."""
-
     @utils.initializer
     def __init__(
         self,
@@ -84,6 +59,7 @@ class GridSearch(BaseSearchClass):
         minStartTime=None,
         maxStartTime=None,
         nsegs=1,
+        singleFstats=False,
         BSGL=False,
         minCoverFreq=None,
         maxCoverFreq=None,
@@ -118,19 +94,20 @@ class GridSearch(BaseSearchClass):
             (do not interpret as 3-tuples of [min,max,step]).
         clean: bool
             If true, ignore existing data and overwrite.
-            Otherwise, re-use existing data if no inconsistencies are found.
+            Otherwise, reuse existing data if no inconsistencies are found.
         """
 
         self._set_init_params_dict(locals())
         os.makedirs(outdir, exist_ok=True)
         self.set_out_file()
-        self.search_keys = ["F0", "F1", "F2", "Alpha", "Delta"]
-        for k in self.search_keys:
+        for k in self.default_search_keys:
             setattr(self, k, np.atleast_1d(getattr(self, k + "s")))
+        self.search_keys = self.default_search_keys.copy()
         if self.BSGL:
             self.detstat = "log10BSGL"
         else:
             self.detstat = "twoF"
+        logger.info(f"Detection statistic set to {self.detstat}.")
         self._initiate_search_object()
         self._set_output_keys()
         self.output_file_header = self.get_output_file_header()
@@ -162,6 +139,7 @@ class GridSearch(BaseSearchClass):
                 detectors=self.detectors,
                 minStartTime=self.minStartTime,
                 maxStartTime=self.maxStartTime,
+                singleFstats=self.singleFstats,
                 BSGL=self.BSGL,
                 SSBprec=self.SSBprec,
                 RngMedWindow=self.RngMedWindow,
@@ -177,6 +155,7 @@ class GridSearch(BaseSearchClass):
                 tref=self.tref,
                 nsegs=self.nsegs,
                 sftfilepattern=self.sftfilepattern,
+                singleFstats=self.singleFstats,
                 BSGL=self.BSGL,
                 minStartTime=self.minStartTime,
                 maxStartTime=self.maxStartTime,
@@ -348,6 +327,45 @@ class GridSearch(BaseSearchClass):
             return False
         return False
 
+    def _get_single_cand_results(self, data, n, vals):
+        """Obtain the results at each grid iteration step.
+
+        Re-formats the input params into the format required by self.search.get_det_stat()
+        and gets additional detection statistic by-products as needed,
+        then stores them all into the right columns of the data array.
+        Can be overridden e.g. for legacy get_det_stat() variants.
+
+        Parameters
+        ----------
+        data: np.ndarray
+            The inputs+outputs data set to be updated.
+        n: int
+            Row index of the data array to update.
+        vals: tuple
+            Iteration of our iterable.
+
+        Returns
+        -------
+        data: np.ndarray
+            The updated inputs+outputs data set.
+        """
+        thisCand = {key: val for key, val in zip(self.search_keys, vals)}
+        detstat = self.search.get_det_stat(params=thisCand)
+        thisCand["twoF"] = self.search.twoF
+        if self.search.singleFstats:
+            for X, IFO in enumerate(self.search.detector_names):
+                thisCand[f"twoF{IFO}"] = self.search.twoFX[X]
+        if self.detstat != "twoF":
+            thisCand[self.detstat] = detstat
+        for key in self.output_keys:
+            if key in thisCand.keys():
+                data[key][n] = thisCand[key]
+            else:  # pragma: no cover
+                raise RuntimeError(
+                    f"Could not get value for key {key} from candidate dict {thisCand}."
+                )
+        return data
+
     def run(self, return_data=False):
         """Execute the actual search over the full grid.
 
@@ -394,15 +412,7 @@ class GridSearch(BaseSearchClass):
         for n, vals in enumerate(
             tqdm(iterable, total=getattr(self, "total_iterations", None))
         ):
-            thisCand = list(vals)
-            detstat = self.search.get_det_stat(*vals)
-            thisCand.append(self.search.twoF)
-            if self.search.singleFstats:
-                thisCand += list(self.search.twoFX[: self.search.numDetectors])
-            if self.detstat != "twoF":
-                thisCand.append(detstat)
-            for k, key in enumerate(self.output_keys):
-                data[key][n] = thisCand[k]
+            data = self._get_single_cand_results(data, n, vals)
 
         if return_data:
             return data
@@ -412,7 +422,9 @@ class GridSearch(BaseSearchClass):
 
     def _get_savetxt_fmt_dict(self):
         """Define the output precision for each parameter and computed quantity."""
-        fmt_dict = utils.get_doppler_params_output_format(self.output_keys)
+        fmt_dict = utils.get_doppler_params_output_format(
+            self.output_keys, self.fmt_doppler
+        )
         fmt_dict["twoF"] = self.fmt_detstat
         if self.search.singleFstats:
             for IFO in self.search.detector_names:
@@ -566,7 +578,7 @@ class GridSearch(BaseSearchClass):
         if xlabel:
             ax.set_xlabel(xlabel)
         elif x0:
-            ax.set_xlabel(self.tex_labels[xkey] + self.tex_labels0[xkey])
+            ax.set_xlabel(self.tex_label0(xkey))
         else:
             ax.set_xlabel(self.tex_labels[xkey])
         if ylabel:
@@ -723,14 +735,14 @@ class GridSearch(BaseSearchClass):
         if xlabel:
             ax.set_xlabel(xlabel)
         elif x0:
-            ax.set_xlabel(self.tex_labels[xkey] + self.tex_labels0[xkey])
+            ax.set_xlabel(self.tex_label0(xkey))
         else:
             ax.set_xlabel(self.tex_labels[xkey])
 
         if ylabel:
             ax.set_ylabel(ylabel)
         elif y0:
-            ax.set_ylabel(self.tex_labels[ykey] + self.tex_labels0[ykey])
+            ax.set_ylabel(self.tex_label0(ykey))
         else:
             ax.set_ylabel(self.tex_labels[ykey])
 
@@ -760,7 +772,7 @@ class GridSearch(BaseSearchClass):
             Dictionary containing parameters and detection statistic at the maximum.
         """
         idx = np.argmax(self.data[self.detstat])
-        d = OrderedDict([(key, self.data[key][idx]) for key in self.output_keys])
+        d = {key: self.data[key][idx] for key in self.output_keys}
         return d
 
     def get_max_twoF(self):
@@ -774,7 +786,7 @@ class GridSearch(BaseSearchClass):
             Dictionary containing parameters and twoF value at the maximum.
         """
         idx = np.argmax(self.data["twoF"])
-        d = OrderedDict([(key, self.data[key][idx]) for key in self.output_keys])
+        d = {key: self.data[key][idx] for key in self.output_keys}
         return d
 
     def print_max_twoF(self):
@@ -791,7 +803,11 @@ class GridSearch(BaseSearchClass):
     def generate_loudest(self):
         """Use ComputeFstatistic_v2 executable to produce a .loudest file"""
         max_params = self.get_max_twoF()
-        max_params.pop("twoF")
+        if "twoF" in max_params.keys():
+            max_params.pop("twoF")
+        for key in [self.detstat, "t0_ML", "tau_ML", "t0_MP", "tau_MP"]:
+            if key in max_params.keys():
+                max_params.pop(key)
         max_params = self.translate_keys_to_lal(max_params)
         self.loudest_file = utils.generate_loudest_file(
             max_params=max_params,
@@ -902,6 +918,7 @@ class TransientGridSearch(GridSearch):
         tref=None,
         minStartTime=None,
         maxStartTime=None,
+        singleFstats=False,
         BSGL=False,
         BtSG=False,
         minCoverFreq=None,
@@ -929,6 +946,9 @@ class TransientGridSearch(GridSearch):
         """
         Parameters
         ----------
+        BtSG: bool
+            If True, compute the transient Bayes factor detection statistic.
+            This search also returns `t0_MP` and `tau_MP` values.
         transientWindowType: str
             If `rect` or `exp`,
             allow for the Fstat to be computed over a transient range.
@@ -956,7 +976,7 @@ class TransientGridSearch(GridSearch):
             If true, write additional output files for the F-stat `atoms`.
             (One file for each grid point!)
         tCWFstatMapVersion: str
-            Choose between implementations of the transient F-statistic funcionality:
+            Choose between implementations of the transient F-statistic functionality:
             standard `lal` implementation,
             `pycuda` for GPU version,
             and some others only for devel/debug.
@@ -969,9 +989,9 @@ class TransientGridSearch(GridSearch):
         self.nsegs = 1
         os.makedirs(outdir, exist_ok=True)
         self.set_out_file()
-        self.search_keys = ["F0", "F1", "F2", "Alpha", "Delta"]
-        for k in self.search_keys:
+        for k in self.default_search_keys:
             setattr(self, k, np.atleast_1d(getattr(self, k + "s")))
+        self.search_keys = self.default_search_keys.copy()
         if self.BSGL and self.BtSG:  # pragma: no cover
             raise ValueError("Please choose only one of [BSGL,BtSG].")
         elif self.BSGL:
@@ -980,6 +1000,7 @@ class TransientGridSearch(GridSearch):
             self.detstat = "lnBtSG"
         else:
             self.detstat = "maxTwoF"
+        logger.info(f"Detection statistic set to {self.detstat}.")
         self._initiate_search_object()
         self._set_output_keys()
         self.output_file_header = self.get_output_file_header()
@@ -1010,13 +1031,15 @@ class TransientGridSearch(GridSearch):
             self.output_keys += [
                 f"twoF{IFO}atMaxTwoF" for IFO in self.search.detector_names
             ]
-        if self.detstat != "maxTwoF":
+        if self.detstat not in ["twoF", "maxTwoF"]:
             self.output_keys.append(self.detstat)
         if self.transientWindowType:
-            # for consistency below, t0/tau must come after detstat
+            # for consistency, t0/tau must come after detstat
             # they are not included in self.search_keys because the main Fstat
             # code does not loop over them
-            self.output_keys += ["t0", "tau"]
+            self.output_keys += ["t0_ML", "tau_ML"]
+            if self.BtSG:
+                self.output_keys += ["t0_MP", "tau_MP"]
 
     def _initiate_search_object(self):
         logger.info("Setting up search object")
@@ -1036,6 +1059,7 @@ class TransientGridSearch(GridSearch):
             dtau=self.dtau,
             minStartTime=self.minStartTime,
             maxStartTime=self.maxStartTime,
+            singleFstats=self.singleFstats,
             BSGL=self.BSGL,
             BtSG=self.BtSG,
             SSBprec=self.SSBprec,
@@ -1053,6 +1077,70 @@ class TransientGridSearch(GridSearch):
         self.minStartTime = self.search.minStartTime
         self.maxStartTime = self.search.maxStartTime
 
+    def _get_single_cand_results(self, data, n, vals):
+        """Obtain the results at each grid iteration step.
+
+        Re-formats the input params into the format required by self.search.get_det_stat()
+        and gets additional detection statistic by-products as needed,
+        then stores them all into the right columns of the data array.
+
+        We override the default method here to get the extra transient output values.
+
+        Parameters
+        ----------
+        data: np.ndarray
+            The inputs+outputs data set to be updated.
+        n: int
+            Row index of the data array to update.
+        vals: tuple
+            Iteration of our iterable.
+
+        Returns
+        -------
+        data: np.ndarray
+            The updated inputs+outputs data set.
+        """
+        thisCand = {key: val for key, val in zip(self.search_keys, vals)}
+        detstat = self.search.get_det_stat(params=thisCand)
+        windowRange = getattr(self.search, "windowRange", None)
+        self.timingFstatMap += getattr(self.search, "timingFstatMap", 0.0)
+        thisCand["twoF"] = self.search.twoF
+        if self.search.singleFstats:
+            for X, IFO in enumerate(self.search.detector_names):
+                thisCand[f"twoF{IFO}"] = self.search.twoFX[X]
+        if windowRange is not None:
+            thisCand["maxTwoF"] = self.search.maxTwoF
+            if hasattr(self.search, "twoFXatMaxTwoF"):
+                for X, IFO in enumerate(self.search.detector_names):
+                    thisCand[f"twoF{IFO}atMaxTwoF"] = self.search.twoFXatMaxTwoF[X]
+        if self.detstat not in ["twoF", "maxTwoF"]:
+            thisCand[self.detstat] = detstat
+        if getattr(self, "transientWindowType", None):
+            if not hasattr(self.search, "FstatMap"):  # pragma: no cover
+                raise RuntimeError(
+                    "Since transientWindowType!=None, we expected to have a FstatMap."
+                )
+            if self.outputTransientFstatMap:
+                tCWfile = self.get_transient_fstat_map_filename(thisCand)
+                self.search.FstatMap.write_F_mn_to_file(
+                    tCWfile, windowRange, self.output_file_header
+                )
+            maxidx = self.search.FstatMap.get_maxF_idx()
+            thisCand["t0_ML"] = windowRange.t0 + maxidx[0] * windowRange.dt0
+            thisCand["tau_ML"] = windowRange.tau + maxidx[1] * windowRange.dtau
+            if self.BtSG:
+                thisCand["t0_MP"] = self.search.FstatMap.t0_MP
+                thisCand["tau_MP"] = self.search.FstatMap.tau_MP
+
+        for key in self.output_keys:
+            if key in thisCand.keys():
+                data[key][n] = thisCand[key]
+            else:  # pragma: no cover
+                raise RuntimeError(
+                    f"Could not get value for key {key} from candidate dict {thisCand}."
+                )
+        return data
+
     def run(self, return_data=False):
         """Execute the actual search over the full grid.
 
@@ -1096,36 +1184,7 @@ class TransientGridSearch(GridSearch):
             )
         )
         for n, vals in enumerate(tqdm(self.input_data)):
-            thisCand = list(vals)
-            detstat = self.search.get_det_stat(*vals)
-            windowRange = getattr(self.search, "windowRange", None)
-            self.timingFstatMap += getattr(self.search, "timingFstatMap", 0.0)
-            thisCand.append(self.search.twoF)
-            if self.search.singleFstats:
-                thisCand += list(self.search.twoFX[: self.search.numDetectors])
-            if hasattr(self.search, "maxTwoF"):
-                thisCand.append(self.search.maxTwoF)
-            if hasattr(self.search, "twoFXatMaxTwoF"):
-                thisCand += list(self.search.twoFXatMaxTwoF[: self.search.numDetectors])
-            if self.detstat != "maxTwoF":
-                thisCand.append(detstat)
-            if getattr(self, "transientWindowType", None):
-                if not hasattr(self.search, "FstatMap"):
-                    raise RuntimeError(
-                        "Since transientWindowType!=None, we expected to have a FstatMap."
-                    )
-                if self.outputTransientFstatMap:
-                    tCWfile = self.get_transient_fstat_map_filename(thisCand)
-                    self.search.FstatMap.write_F_mn_to_file(
-                        tCWfile, windowRange, self.output_file_header
-                    )
-                maxidx = self.search.FstatMap.get_maxF_idx()
-                thisCand += [
-                    windowRange.t0 + maxidx[0] * windowRange.dt0,
-                    windowRange.tau + maxidx[1] * windowRange.dtau,
-                ]
-            for k, key in enumerate(self.output_keys):
-                data[key][n] = thisCand[k]
+            data = self._get_single_cand_results(data, n, vals)
             if self.outputAtoms:
                 self.search.write_atoms_to_file(os.path.splitext(self.out_file)[0])
 
@@ -1144,6 +1203,8 @@ class TransientGridSearch(GridSearch):
     def get_transient_fstat_map_filename(self, param_point):
         """Filename convention for given grid point: freq_alpha_delta_f1dot_f2dot
 
+        FIXME: This does not yet deal properly with spindown terms higher than F2!
+
         Parameters
         ----------
         param_point: tuple, dict, list, np.void or np.ndarray
@@ -1171,7 +1232,9 @@ class TransientGridSearch(GridSearch):
 
     def _get_savetxt_fmt_dict(self):
         """Define the output precision for each parameter and computed quantity."""
-        fmt_dict = utils.get_doppler_params_output_format(self.output_keys)
+        fmt_dict = utils.get_doppler_params_output_format(
+            self.output_keys, self.fmt_doppler
+        )
         fmt_dict["twoF"] = self.fmt_detstat
         if self.search.singleFstats:
             for IFO in self.search.detector_names:
@@ -1182,11 +1245,264 @@ class TransientGridSearch(GridSearch):
                 fmt_dict[f"twoF{IFO}atMaxTwoF"] = self.fmt_detstat
         if self.detstat != "maxTwoF":
             fmt_dict[self.detstat] = self.fmt_detstat
-        fmt_dict["t0"] = "%d"
-        fmt_dict["tau"] = "%d"
+        fmt_dict["t0_ML"] = "%d"
+        fmt_dict["tau_ML"] = "%d"
+        if self.BtSG:
+            fmt_dict["t0_MP"] = "%d"
+            fmt_dict["tau_MP"] = "%d"
         return fmt_dict
 
 
+class SearchOverGridFile(TransientGridSearch):
+    """A search over a grid defined in an input text file.
+
+    Such a file can be generated for example with
+    lalapps_ComputeFstatistic_v2 using the --outputGrid option.
+
+    WARNING: The header file of the grid file is NOT yet parsed
+    for consistency of CFSv2 options (such as reference time)
+    with the PyFstat options,
+    so please ensure yourself that these match!
+
+    Most parameters are the same as for `GridSearch`, `TransientGridSearch`
+    and the `core.ComputeFstat` class,
+    only the additional ones are documented here.
+
+    NOTE: `nsegs>1` is incompatible with transient options.
+    """
+
+    @utils.initializer
+    def __init__(
+        self,
+        label,
+        outdir,
+        sftfilepattern,
+        gridfile,
+        tref,
+        minStartTime=None,
+        maxStartTime=None,
+        nsegs=1,
+        singleFstats=False,
+        BSGL=False,
+        BtSG=False,
+        minCoverFreq=None,
+        maxCoverFreq=None,
+        detectors=None,
+        SSBprec=None,
+        RngMedWindow=None,
+        injectSources=None,
+        input_arrays=False,
+        assumeSqrtSX=None,
+        transientWindowType=None,
+        t0Band=None,
+        tauBand=None,
+        tauMin=None,
+        dt0=None,
+        dtau=None,
+        outputTransientFstatMap=False,
+        outputAtoms=False,
+        tCWFstatMapVersion="lal",
+        cudaDeviceName=None,
+        earth_ephem=None,
+        sun_ephem=None,
+        clean=False,
+        reading_method="numpy",
+    ):
+        """
+        Parameters
+        ----------
+        gridfile: str
+            filename of the grid file to load
+        reading_method: str
+            Currently, grid files can be read with either `numpy` or `pandas`.
+            Pandas is expected to be faster for large files.
+        """
+
+        self._set_init_params_dict(locals())
+        if self.nsegs > 1 and self.transientWindowType is not None:  # pragma: no cover
+            raise ValueError(
+                f"nsegs={self.nsegs} is incompatible with transient options (transientWindowType={self.transientWindowType})."
+            )
+        os.makedirs(outdir, exist_ok=True)
+        self.set_out_file()
+        if reading_method == "numpy":
+            self._read_grid_with_numpy()
+        elif reading_method == "pandas":
+            self._read_grid_with_pandas()
+        else:  # pragma: no cover
+            raise ValueError(
+                f"Invalid reading method: {reading_method}. Expected 'numpy' or 'pandas'."
+            )
+        self.search_keys = list(self.grid.dtype.names)
+        if self.BSGL and self.BtSG:  # pragma: no cover
+            raise ValueError("Please choose only one of [BSGL,BtSG].")
+        if self.BSGL:
+            self.detstat = "log10BSGL"
+        elif self.BtSG:
+            self.detstat = "lnBtSG"
+        elif self.transientWindowType is not None:
+            self.detstat = "maxTwoF"
+        else:
+            self.detstat = "twoF"
+        logger.info(f"Detection statistic set to {self.detstat}.")
+        self._initiate_search_object()
+        self._set_output_keys()
+        self.output_file_header = self.get_output_file_header()
+        if self.outputTransientFstatMap:
+            self.tCWfilebase = os.path.splitext(self.out_file)[0] + "_tCW_"
+            logger.info(
+                "Will save per-Doppler Fstatmap"
+                " results to {}*.dat".format(self.tCWfilebase)
+            )
+
+    def _read_grid_with_pandas(self):
+        """Use pandas, but purely as a reading backend.
+
+        This should be faster for large grids.
+        But we convert back to a standard numpy array at the end.
+        """
+
+        logger.info(f"Loading grid from file using pandas backend: {self.gridfile}")
+        nhead = 0
+        with open(self.gridfile, "r") as fp:
+            for line in fp:
+                if not line.startswith("%%"):
+                    break
+                nhead += 1
+
+        pd_grid = pd.read_csv(
+            self.gridfile,
+            comment="%",
+            sep="\\s+",  # whitespace
+            engine="c",
+            header=None,  # Do not infer headers
+            names=[
+                "F0",
+                "Alpha",
+                "Delta",
+                "F1",
+                "F2",
+                "F3",
+            ],
+            skiprows=nhead,  # Skip the first `nhead` rows (comments)
+        )
+        logger.info(
+            f"Successfully loaded grid of size {pd_grid.shape} as a pandas DataFrame."
+        )
+
+        # Map Pandas dtypes to NumPy-compatible dtypes
+        mapped_dtypes = {
+            "float64": "f8",
+            "int64": "i8",
+            "object": "U",  # Adjust for string columns if needed
+        }
+        numpy_dtypes = [
+            (col, mapped_dtypes[str(dtype)])
+            for col, dtype in zip(pd_grid.columns, pd_grid.dtypes)
+        ]
+        try:
+            self.grid = np.array(
+                list(pd_grid.itertuples(index=False, name=None)), dtype=numpy_dtypes
+            )
+        except Exception as e:  # pragma: no cover
+            raise TypeError(f"Failed to convert pandas DataFrame to NumPy array: {e}")
+        if len(pd_grid) == 0:  # pragma: no cover
+            raise IOError("Got 0-length grid.")
+        logger.info("Successfully converted to NumPy array with the following dtype:")
+        logger.info(self.grid.dtype)
+        self.grid.dtype.names = self._translate_keys_from_cfsv2(self.grid.dtype.names)
+        logger.info("Updated dtype to match PyFstat parameter naming convention:")
+        logger.info(self.grid.dtype)
+
+    def _read_grid_with_numpy(self):
+        logger.info(f"Loading grid from file using NumPy backend: {self.gridfile}")
+        nhead = 0
+        with open(self.gridfile, "r") as fp:
+            for line in fp:
+                if not line.startswith("%%"):
+                    break
+                nhead += 1
+        self.grid = np.genfromtxt(
+            self.gridfile,
+            comments="%",
+            skip_header=nhead - 1,
+            names=True,
+        )
+        if len(self.grid) == 0:  # pragma: no cover
+            raise IOError("Got 0-length grid.")
+        logger.info(
+            f"Successfully loaded grid as NumPy array of size {np.shape(self.grid)}"
+            " with the following dtype:"
+        )
+        logger.info(self.grid.dtype)
+        self.grid.dtype.names = self._translate_keys_from_cfsv2(self.grid.dtype.names)
+        logger.info("Updated dtype to match PyFstat parameter naming convention:")
+        logger.info(self.grid.dtype)
+
+    def _translate_keys_from_cfsv2(self, keylist):
+        """Convert grid column heading keys into PyFstat convention.
+
+        In our convention, input keys (search parameter names)
+        are F0, F1, F2, ...,
+        while CFSv2 grid file headers are freq, f1dot, f2dot, ....
+
+        This is sort of an inverse to core's translate_keys_to_lal(),
+        just for a list instead of a dict.
+        Also unfortunately, in this type of files parameters are all lower-cased,
+        inconsistent with other parts of lalpulsar/lalapps.
+
+        Parameters
+        ----------
+        keylist: list
+            List of parameters to translate. A copy will be returned.
+
+        Returns
+        -------
+        translated: list
+            Copy of "keylist" with new keys according to PyFstat convention.
+        """
+
+        translation = {
+            "freq": "F0",
+            "alpha": "Alpha",
+            "delta": "Delta",
+        }
+        translation.update(
+            {f"f{k + 1}dot": f"F{k + 1}" for k in range(lalpulsar.PULSAR_MAX_SPINS - 1)}
+        )
+
+        translated = [
+            translation[key] if key in translation.keys() else key for key in keylist
+        ]
+
+        return translated
+
+    def _get_search_ranges(self):
+        logger.info("Getting search ranges...")
+        if (self.minCoverFreq is None) or (self.maxCoverFreq is None):
+            minmaxdict = {
+                key: [np.min(self.grid[key]), np.max(self.grid[key])]
+                for key in self.search_keys
+            }
+            logger.info(f"Search ranges span: {minmaxdict}")
+            return minmaxdict
+        else:
+            return None
+
+    def _get_input_data_array(self):
+        """Set up an input data array from the previously loaded grid.
+
+        This is a numpy structured array with named columns
+        and explicit dtype (cannot have named columns without that).
+        """
+
+        logger.info("Generating input data array from loaded grid.")
+        self.coord_arrays = self.grid
+        self.total_iterations = len(self.grid)
+        if not self.clean:
+            self.input_data = self.grid
+
+
 class SliceGridSearch(DefunctClass):
     last_supported_version = "1.9.0"
 
@@ -1223,6 +1539,7 @@ class GridGlitchSearch(GridSearch):
         tref=None,
         minStartTime=None,
         maxStartTime=None,
+        singleFstats=False,
         minCoverFreq=None,
         maxCoverFreq=None,
         detectors=None,
@@ -1256,12 +1573,7 @@ class GridGlitchSearch(GridSearch):
         self.input_arrays = False
         if tglitchs is None:
             raise ValueError("You must specify `tglitchs`")
-        self.search_keys = [
-            "F0",
-            "F1",
-            "F2",
-            "Alpha",
-            "Delta",
+        self.search_keys = self.default_search_keys + [
             "delta_F0",
             "delta_F1",
             "tglitch",
@@ -1286,6 +1598,7 @@ class GridGlitchSearch(GridSearch):
             minCoverFreq=self.minCoverFreq,
             maxCoverFreq=self.maxCoverFreq,
             search_ranges=search_ranges,
+            singleFstats=self.singleFstats,
             BSGL=self.BSGL,
             earth_ephem=self.earth_ephem,
             sun_ephem=self.sun_ephem,
@@ -1293,13 +1606,48 @@ class GridGlitchSearch(GridSearch):
 
     def _get_savetxt_fmt_dict(self):
         """Define the output precision for each parameter and computed quantity."""
-        fmt_dict = utils.get_doppler_params_output_format(self.output_keys)
-        fmt_dict["delta_F0"] = "%.16g"
-        fmt_dict["delta_F1"] = "%.16g"
+        fmt_dict = utils.get_doppler_params_output_format(
+            self.output_keys, self.fmt_doppler
+        )
+        fmt_dict["delta_F0"] = self.fmt_doppler
+        fmt_dict["delta_F1"] = self.fmt_doppler
         fmt_dict["tglitch"] = "%d"
         fmt_dict[self.detstat] = self.fmt_detstat
         return fmt_dict
 
+    def _get_single_cand_results(self, data, n, vals):
+        """Obtain the results at each grid iteration step.
+
+        FIXME: currently we need to override the default method here
+        because the SemiCoherentGlitchSearch.get_semicoherent_nglitch_twoF()
+        is not yet ported to the new parameter dictionary style
+        of other detection statistics methods.
+
+        Parameters
+        ----------
+        data: np.ndarray
+            The inputs+outputs data set to be updated.
+        n: int
+            Row index of the data array to update.
+        vals: tuple
+            Iteration of our iterable.
+
+        Returns
+        -------
+        data: np.ndarray
+            The updated inputs+outputs data set.
+        """
+        thisCand = list(vals)
+        detstat = self.search.get_det_stat(*vals)
+        thisCand.append(self.search.twoF)
+        if self.search.singleFstats:
+            thisCand += list(self.search.twoFX[: self.search.numDetectors])
+        if self.detstat != "twoF":
+            thisCand.append(detstat)
+        for k, key in enumerate(self.output_keys):
+            data[key][n] = thisCand[k]
+        return data
+
 
 class SlidingWindow(DefunctClass):
     last_supported_version = "1.9.0"
