@@ -4,7 +4,6 @@ Provides functions to aid in calculating the optimal setup for zoom follow up
 
 """
 
-
 import logging
 
 import lal
@@ -100,7 +99,7 @@ def _get_nsegs_ip1(
 
     Raises
     ------
-    ValueError: Optimisation unsuccesful
+    ValueError: Optimisation unsuccessful
         A value error is raised if the optimization step fails
 
     """
@@ -144,7 +143,7 @@ def _get_nsegs_ip1(
             ),
         )
     else:
-        raise ValueError("Optimisation unsuccesful")
+        raise ValueError("Optimisation unsuccessful")
 
 
 def _extract_data_from_prior(prior):
@@ -173,7 +172,7 @@ def _extract_data_from_prior(prior):
     lims_keys = []
     lims_idxs = []
     for i, key in enumerate(keys):
-        if type(prior[key]) == dict:
+        if isinstance(prior[key], dict):
             if prior[key]["type"] == "unif":
                 lims.append([prior[key]["lower"], prior[key]["upper"]])
                 lims_keys.append(key)
@@ -194,7 +193,7 @@ def _extract_data_from_prior(prior):
         p.append(basex)
     spindowns = int(np.sum([np.sum(lims_keys == k) for k in spindown_keys]))
     sky = any([key in lims_keys for key in sky_keys])
-    if type(prior["F0"]) == dict:
+    if isinstance(prior["F0"], dict):
         fiducial_freq = prior["F0"]["upper"]
     else:
         fiducial_freq = prior["F0"]
