@@ -80,6 +80,16 @@ class pyTransientFstatMap:
         Natural log of the marginalised transient Bayes factor.
         NOTE: This is always initialised as `nan`,
         and you have to call `get_lnBtSG()` to get its actual value.
+    t0_MP: float
+        Maximum posterior estimate of the transient start time `t0`.
+        NOTE: This is always initialised as `nan`,
+        and you have to call `get_t0_max_posterior()` to get its actual value
+        (or its LALpular equivalent).
+    tau_MP: float
+        Maximum posterior estimate of the transient duration `tau`.
+        NOTE: This is always initialised as `nan`,
+        and you have to call `get_tau_max_posterior()` to get its actual value
+        (or its LALpular equivalent).
     """
 
     def __init__(
@@ -130,6 +140,8 @@ class pyTransientFstatMap:
             self.t0_ML = float(0.0)
             self.tau_ML = float(0.0)
         self.lnBtSG = np.nan
+        self.t0_MP = np.nan
+        self.tau_MP = np.nan
 
     def _init_from_lalpulsar_type(self, transientFstatMap_t):
         """This essentially just strips out a redundant member level from the lalpulsar structure.
@@ -204,6 +216,76 @@ class pyTransientFstatMap:
         self.lnBtSG = np.log(normBh) + logBhat  # - 4.0 * log ( rhohMax )
         return self.lnBtSG
 
+    def get_t0_max_posterior(self, windowRange):
+        """Compute transient-CW max-posterior estimate on start-time t0.
+
+        This is based on `XLALComputeTransientPosterior_t0()`,
+        dropping the special cases and normalization step,
+        and only returning the maximum point, not a full posterior.
+
+        The posterior is sampled with N_t0Range points given by the size
+        of the input matrix  FstatMap (namely N_t0Range = t0Band / dt0).
+
+        Consistent with `XLALFindModeOfPDF1D()`,
+        we return the center-value of the discrete 'bin'
+        containing the maximum of the distribution.
+
+        Parameters
+        ----------
+        windowRange: lalpulsar.transientWindowRange_t
+            A lalpulsar structure containing the transient parameters.
+
+        Returns
+        -------
+        t0_MP: float
+            The max-posterior estimate of start time t0 [in s].
+        """
+        # Subtract maxF from F_mn and sum up e^{F_mn - maxF}.
+        # It is numerically more robust to marginalize over e^(F_mn - Fmax),
+        # which at worst can underflow, while e^F_mn can overflow.
+        # The constant offset e^Fmax is irrelevant for posteriors (normalization constant).
+        sum_eF = np.sum(np.exp(-(self.maxF - self.F_mn)), axis=1)
+        dx = windowRange.t0Band / (
+            np.shape(self.F_mn)[0]
+        )  # like this it is consistent with LAL
+        self.t0_MP = windowRange.t0 + (np.argmax(sum_eF) + 0.5) * dx  # windowRange.dt0
+        return self.t0_MP
+
+    def get_tau_max_posterior(self, windowRange):
+        """Compute transient-CW max-posterior estimate on timescale tau.
+
+        This is based on `XLALComputeTransientPosterior_tau(),`
+        dropping the special cases and normalization step,
+        and only returning the maximum point, not a full posterior.
+
+        The posterior is sampled with N_tauRange points given by the size
+        of the input matrix  FstatMap (namely N_tauRange = tauBand / dtau).
+
+        Consistent with `XLALFindModeOfPDF1D()`,
+        we return the center-value of the discrete 'bin'
+        containing the maximum of the distribution.
+
+        Parameters
+        ----------
+        windowRange: lalpulsar.transientWindowRange_t
+            A lalpulsar structure containing the transient parameters.
+
+        Returns
+        -------
+        tau_MP: float
+            The max-posterior estimate of timescale tau [in s].
+        """
+        # Subtract maxF from F_mn and sum up e^{F_mn - maxF}.
+        # It is numerically more robust to marginalize over e^(F_mn - Fmax),
+        # which at worst can underflow, while e^F_mn can overflow.
+        # The constant offset e^Fmax is irrelevant for posteriors (normalization constant).
+        sum_eF = np.sum(np.exp(-(self.maxF - self.F_mn)), axis=0)
+        dy = windowRange.tauBand / (
+            np.shape(self.F_mn)[1]
+        )  # like this it is consistent with LAL
+        self.tau_MP = windowRange.tau + (np.argmax(sum_eF) + 0.5) * dy
+        return self.tau_MP
+
     def write_F_mn_to_file(self, tCWfile, windowRange, header=[]):
         """Format a 2D transient-F-stat matrix over `(t0,tau)` and write as a text file.
 
@@ -266,6 +348,16 @@ def _optional_imports_pycuda():
     )
 
 
+def _get_transient_fstat_map_features():
+    """Helper function to check available features."""
+    features = {}
+    have_lal = _optional_import("lal")
+    have_lalpulsar = _optional_import("lalpulsar")
+    features["lal"] = have_lal and have_lalpulsar
+    features["pycuda"] = _optional_imports_pycuda()
+    return features
+
+
 def init_transient_fstat_map_features(feature="lal", cudaDeviceName=None):
     """Initialization of available modules (or 'features') for computing transient F-stat maps.
 
@@ -296,18 +388,14 @@ def init_transient_fstat_map_features(feature="lal", cudaDeviceName=None):
         A CUDA device context object, if assigned.
     """
 
-    features = {}
-    have_lal = _optional_import("lal")
-    have_lalpulsar = _optional_import("lalpulsar")
-    features["lal"] = have_lal and have_lalpulsar
-    features["pycuda"] = _optional_imports_pycuda()
+    features = _get_transient_fstat_map_features()
     logger.debug("Got the following features for transient F-stat maps:")
     logger.debug(features)
 
     if feature == "pycuda":
         if not features["pycuda"]:
             raise RuntimeError("pycuda use was requested, but imports failed.")
-        logger.debug("CUDA version: " + ".".join(map(str, drv.get_version())))
+        logger.info("CUDA version: " + ".".join(map(str, drv.get_version())))
 
         drv.init()
         logger.debug(
@@ -329,7 +417,7 @@ def init_transient_fstat_map_features(feature="lal", cudaDeviceName=None):
                 raise pycuda._driver.LogicError(e.message)
 
         num_gpus = drv.Device.count()
-        logger.debug("Found {} CUDA device(s).".format(num_gpus))
+        logger.info("Found {} CUDA device(s).".format(num_gpus))
 
         devices = []
         devnames = np.empty(num_gpus, dtype="S32")
@@ -337,7 +425,7 @@ def init_transient_fstat_map_features(feature="lal", cudaDeviceName=None):
             devn = drv.Device(n)
             devices.append(devn)
             devnames[n] = devn.name().replace(" ", "-").replace("_", "-")
-            logger.debug(
+            logger.info(
                 "device {}: model: {}, RAM: {}MB".format(
                     n, devnames[n], devn.total_memory() / (2.0**20)
                 )
@@ -471,7 +559,9 @@ def lalpulsar_compute_transient_fstat_map(multiFstatAtoms, windowRange, BtSG=Fal
     BtSG: boolean
         If true, also compute the lnBtSG transient Bayes factor statistic,
         using the corresponding lalpulsar function,
-        and store it in `FstatMap.lnBtSG`.
+        and store it in `FstatMap.lnBtSG`;
+        and the max-posterior estimates
+        `FstatMap.t0_MP` and `FstatMap.tau_MP`.
 
     Returns
     -------
@@ -488,6 +578,12 @@ def lalpulsar_compute_transient_fstat_map(multiFstatAtoms, windowRange, BtSG=Fal
         FstatMap.lnBtSG = lalpulsar.ComputeTransientBstat(
             windowRange, FstatMap_lalpulsar
         )
+        pdf_t0 = lalpulsar.ComputeTransientPosterior_t0(windowRange, FstatMap_lalpulsar)
+        pdf_tau = lalpulsar.ComputeTransientPosterior_tau(
+            windowRange, FstatMap_lalpulsar
+        )
+        FstatMap.t0_MP = lalpulsar.FindModeOfPDF1D(pdf_t0)
+        FstatMap.tau_MP = lalpulsar.FindModeOfPDF1D(pdf_tau)
     return FstatMap
 
 
@@ -571,7 +667,7 @@ def pycuda_compute_transient_fstat_map(multiFstatAtoms, windowRange, BtSG=False)
     the actual CUDA computations are performed in one of the functions
     `pycuda_compute_transient_fstat_map_rect()`
     or `pycuda_compute_transient_fstat_map_exp()`,
-    depending on the window functon defined in `windowRange`.
+    depending on the window function defined in `windowRange`.
 
     Parameters
     ----------
@@ -582,7 +678,9 @@ def pycuda_compute_transient_fstat_map(multiFstatAtoms, windowRange, BtSG=False)
     BtSG: boolean
         If true, also compute the lnBtSG transient Bayes factor statistic,
         using a CPU python port of the corresponding lalpulsar function,
-        and store it in `FstatMap.lnBtSG`.
+        and store it in `FstatMap.lnBtSG`;
+        and the max-posterior estimates
+        `FstatMap.t0_MP` and `FstatMap.tau_MP`.
 
     Returns
     -------
@@ -725,8 +823,13 @@ def pycuda_compute_transient_fstat_map(multiFstatAtoms, windowRange, BtSG=False)
 
     if BtSG:
         # so far seems there is no need to move this onto the GPU
-        FstatMap.lnBtSG = FstatMap.get_lnBtSG()
-        logger.debug(f"Also computed: lnBtSG={FstatMap.lnBtSG:.4f}")
+        FstatMap.get_lnBtSG()
+        FstatMap.get_t0_max_posterior(windowRange)
+        FstatMap.get_tau_max_posterior(windowRange)
+        logger.debug(
+            f"Also computed: lnBtSG={FstatMap.lnBtSG:.4f},"
+            f" t0_MP={FstatMap.t0_MP}, tau_MP={FstatMap.tau_MP}"
+        )
 
     return FstatMap
 
@@ -736,7 +839,7 @@ def pycuda_compute_transient_fstat_map_rect(atomsInputMatrix, windowRange, tCWpa
 
     As discussed in Keitel & Ashton (CQG 35, 205003, 2018):
     https://arxiv.org/abs/1805.05652
-    this version only does GPU parallization for the outer loop,
+    this version only does GPU parallelization for the outer loop,
     keeping the partial sums of the inner loop local to each individual kernel
     using the 'memory trick'.
 
@@ -818,7 +921,7 @@ def pycuda_compute_transient_fstat_map_exp(atomsInputMatrix, windowRange, tCWpar
 
     As discussed in Keitel & Ashton (CQG 35, 205003, 2018):
     https://arxiv.org/abs/1805.05652
-    this version does full GPU parallization
+    this version does full GPU parallelization
     of both the inner and outer loop.
 
     Parameters
