@@ -9,6 +9,7 @@ import pytest
 from commons_for_tests import (
     BaseForTestsWithData,
     BaseForTestsWithOutdir,
+    default_binary_params,
     default_signal_params,
     default_Writer_params,
 )
@@ -120,7 +121,10 @@ class TestPredictFstat(BaseForTestsWithOutdir):
         params["transient_tstart"] = default_Writer_params["tstart"]
         params["transient_duration"] = 0.5 * duration
         params = pyfstat.utils.get_predict_fstat_parameters_from_dict(params)
-        (twoF_expected_transient, twoF_sigma_transient,) = pyfstat.utils.predict_fstat(
+        (
+            twoF_expected_transient,
+            twoF_sigma_transient,
+        ) = pyfstat.utils.predict_fstat(
             **params,
             minStartTime=default_Writer_params["tstart"],
             duration=duration,
@@ -153,6 +157,7 @@ class TestComputeFstat(BaseForTestsWithData):
             minCoverFreq=self.F0 - 0.1,
             maxCoverFreq=self.F0 + 0.1,
         )
+        # FIXME: This way is deprecated, remove test in future versions
         FS = search.get_fullycoherent_twoF(
             F0=self.F0,
             F1=self.F1,
@@ -161,9 +166,68 @@ class TestComputeFstat(BaseForTestsWithData):
             Delta=self.Delta,
         )
         self.assertTrue(FS > 0.0)
+        # now with new input params option
+        FS_new = search.get_fullycoherent_twoF(
+            params={
+                "F0": self.F0,
+                "F1": self.F1,
+                "F2": self.F2,
+                "Alpha": self.Alpha,
+                "Delta": self.Delta,
+            }
+        )
+        np.isclose(FS_new, FS, rtol=1e-6, atol=0)
+        # now with higher spindowns
+        FS_sd = search.get_fullycoherent_twoF(
+            params={
+                "F0": self.F0,
+                "F1": self.F1,
+                "F2": self.F2,
+                # deliberately skipping F3 to test non-contiguous lists
+                # (omtited terms should be assumed as 0)
+                "F4": 1e-20,
+                "Alpha": self.Alpha,
+                "Delta": self.Delta,
+            }
+        )
+        np.isclose(FS_sd, FS, rtol=1e-6, atol=0)
+        # FIXME: extend test to properly test Fkdot matches?
+
+    def test_run_computefstatistic_single_point_injectSqrtSX_binary(self):
+        # not using any SFTs
+        search = pyfstat.ComputeFstat(
+            tref=self.tref,
+            minStartTime=self.tstart,
+            maxStartTime=self.tstart + self.duration,
+            detectors=self.detectors,
+            injectSqrtSX=self.sqrtSX,
+            minCoverFreq=self.F0 - 0.1,
+            maxCoverFreq=self.F0 + 0.1,
+            binary=True,
+        )
+        # FIXME: This way is deprecated, remove test in future versions
+        FS = search.get_fullycoherent_twoF(
+            F0=self.F0,
+            F1=self.F1,
+            F2=self.F2,
+            Alpha=self.Alpha,
+            Delta=self.Delta,
+            **default_binary_params,
+        )
+        self.assertTrue(FS > 0.0)
+        # now with new input params option
+        params = {
+            "F0": self.F0,
+            "F1": self.F1,
+            "F2": self.F2,
+            "Alpha": self.Alpha,
+            "Delta": self.Delta,
+        }
+        params.update(default_binary_params)
+        FS = search.get_fullycoherent_twoF(params=params)
+        self.assertTrue(FS > 0.0)
 
     def test_run_computefstatistic_single_point_with_SFTs(self):
-
         twoF_predicted = self.Writer.predict_fstat()
 
         search = pyfstat.ComputeFstat(
@@ -219,11 +283,10 @@ class TestComputeFstat(BaseForTestsWithData):
         self.assertTrue(diff < 0.001)
 
     def test_run_computefstatistic_allowedMismatchFromSFTLength(self):
-
         long_Tsft_params = default_Writer_params.copy()
         long_Tsft_params["Tsft"] = 3600
         long_Tsft_params["duration"] = 4 * long_Tsft_params["Tsft"]
-        long_Tsft_params["label"] = "long_Tsft"
+        long_Tsft_params["label"] = "longTsft"
         long_Tsft_params["F0"] = 1500
         long_Tsft_params["Band"] = 2.0
         long_Tsft_Writer = pyfstat.Writer(**long_Tsft_params)
@@ -249,7 +312,6 @@ class TestComputeFstat(BaseForTestsWithData):
         search.get_fullycoherent_twoF(F0=1500, F1=0, F2=0, Alpha=0, Delta=0)
 
     def test_run_computefstatistic_single_point_injectSources(self):
-
         predicted_FS = self.Writer.predict_fstat()
 
         injectSources = self.Writer.config_file_name
@@ -514,6 +576,13 @@ class TestComputeFstat(BaseForTestsWithData):
             places=4,
             msg=f"search1.twoF={search1.twoF}, search2.twoF={search2.twoF}",
         )
+        Ndet = len(search2.detectors.split(","))
+        for X in range(Ndet):
+            print(search2.twoFX[X])
+            self.assertTrue(
+                search2.twoFX[X] > 0,
+                msg=f"search2.twoFX={search1.twoFX} but the first {Ndet} entries should be non-zero.",
+            )
         self.assertAlmostEqual(
             search1.maxTwoF,
             search2.maxTwoF,
@@ -728,7 +797,6 @@ class TestComputeFstatNoNoise(BaseForTestsWithData):
     sqrtSX = 0
 
     def test_run_computefstatistic_single_point_no_noise(self):
-
         predicted_FS = self.Writer.predict_fstat(assumeSqrtSX=1)
         search = pyfstat.ComputeFstat(
             tref=self.Writer.tref,
@@ -746,7 +814,6 @@ class TestComputeFstatNoNoise(BaseForTestsWithData):
         self.assertTrue(np.abs(predicted_FS - FS) / FS < 0.3)
 
     def test_run_computefstatistic_single_point_no_noise_manual_ephem(self):
-
         predicted_FS = self.Writer.predict_fstat(assumeSqrtSX=1)
 
         # let's get the default ephemeris files (to be sure their paths exist)
@@ -828,7 +895,6 @@ class TestSemiCoherentSearch(BaseForTestsWithData):
     nsegs = 2
 
     def test_get_semicoherent_twoF(self):
-
         search = pyfstat.SemiCoherentSearch(
             label=self.label,
             outdir=self.outdir,
@@ -947,11 +1013,10 @@ class TestSemiCoherentSearch(BaseForTestsWithData):
         self._test_get_semicoherent_BSGL(**dataopts)
 
     def test_get_semicoherent_twoF_allowedMismatchFromSFTLength(self):
-
         long_Tsft_params = default_Writer_params.copy()
         long_Tsft_params["Tsft"] = 3600
         long_Tsft_params["duration"] = 4 * long_Tsft_params["Tsft"]
-        long_Tsft_params["label"] = "long_Tsft"
+        long_Tsft_params["label"] = "longTsft"
         long_Tsft_params["F0"] = 1500
         long_Tsft_params["Band"] = 2.0
         long_Tsft_Writer = pyfstat.Writer(**long_Tsft_params)
@@ -989,7 +1054,6 @@ class TestSemiCoherentGlitchSearch(BaseForTestsWithData):
     Band = 1
 
     def _run_test(self, delta_F0):
-
         Writer = pyfstat.GlitchWriter(
             self.label,
             outdir=self.outdir,
@@ -1001,7 +1065,7 @@ class TestSemiCoherentGlitchSearch(BaseForTestsWithData):
             sqrtSX=self.sqrtSX,
             **default_signal_params,
             SFTWindowType=self.SFTWindowType,
-            SFTWindowBeta=self.SFTWindowBeta,
+            SFTWindowParam=self.SFTWindowParam,
             randSeed=self.randSeed,
             Band=self.Band,
         )
