@@ -101,7 +101,6 @@ class TestMCMCSearch(BaseForMCMCSearchTests):
     BSGL = False
 
     def test_fully_coherent_MCMC(self):
-
         # use a single test case with loop over multiple prior choices
         # this could be much more elegantly done with @pytest.mark.parametrize
         # but that cannot be mixed with unittest classes
@@ -194,6 +193,7 @@ class TestMCMCSearch(BaseForMCMCSearchTests):
             )
             self.search.run(plot_walkers=False)
             self.search.print_summary()
+            self.search.write_prior_table()
             self._check_twoF_predicted()
             self._check_mcmc_quantiles()
             self._test_plots()
@@ -212,7 +212,7 @@ class TestMCMCSearchBSGL(TestMCMCSearch):
         SFTs_H1 = self.Writer.sftfilepath.split(";")[0]
         SFTs_L1 = self.Writer.sftfilepath.split(";")[1]
         extra_writer = pyfstat.Writer(
-            label=self.label + "_with_line",
+            label=self.label + "WithLine",
             outdir=self.outdir,
             tref=self.tref,
             F0=self.Writer.F0 + 0.5e-2,
@@ -225,7 +225,7 @@ class TestMCMCSearchBSGL(TestMCMCSearch):
             sqrtSX=0,  # don't add yet another set of Gaussian noise
             noiseSFTs=SFTs_H1,
             SFTWindowType=self.Writer.SFTWindowType,
-            SFTWindowBeta=self.Writer.SFTWindowBeta,
+            SFTWindowParam=self.Writer.SFTWindowParam,
         )
         extra_writer.make_data()
         data_with_line = ";".join([SFTs_L1, extra_writer.sftfilepath])
@@ -243,7 +243,7 @@ class TestMCMCSearchBSGL(TestMCMCSearch):
         }
         # now run a standard F-stat search over this data
         self.search = pyfstat.MCMCSearch(
-            label=self.label + "-F",
+            label=self.label + "F",
             outdir=self.outdir,
             theta_prior=thetas,
             tref=self.tref,
@@ -267,7 +267,7 @@ class TestMCMCSearchBSGL(TestMCMCSearch):
         self._test_plots()
         # also run a BSGL search over the same data
         self.search = pyfstat.MCMCSearch(
-            label=self.label + "-BSGL",
+            label=self.label + "BSGL",
             outdir=self.outdir,
             theta_prior=thetas,
             tref=self.tref,
@@ -301,7 +301,6 @@ class TestMCMCSemiCoherentSearch(BaseForMCMCSearchTests):
     label = "TestMCMCSemiCoherentSearch"
 
     def test_semi_coherent_MCMC(self):
-
         theta = {
             "F0": {
                 "type": "unif",
@@ -362,7 +361,6 @@ class TestMCMCFollowUpSearch(BaseForMCMCSearchTests):
     h0 = 0.1
 
     def test_MCMC_followup_search(self):
-
         theta = {
             "F0": {
                 "type": "unif",
@@ -421,7 +419,7 @@ class TestMCMCTransientSearch(BaseForMCMCSearchTests):
             Band=self.Band,
             detectors=self.detectors,
             SFTWindowType=self.SFTWindowType,
-            SFTWindowBeta=self.SFTWindowBeta,
+            SFTWindowParam=self.SFTWindowParam,
             randSeed=self.randSeed,
             transientWindowType=self.transientWindowType,
             transientStartTime=self.transientStartTime,
@@ -443,7 +441,6 @@ class TestMCMCTransientSearch(BaseForMCMCSearchTests):
         }
 
     def test_transient_MCMC_t0only(self):
-
         theta = {
             **self.basic_theta,
             "transient_tstart": {
@@ -469,7 +466,6 @@ class TestMCMCTransientSearch(BaseForMCMCSearchTests):
         self._test_plots()
 
     def test_transient_MCMC_tauonly(self):
-
         theta = {
             **self.basic_theta,
             "transient_tstart": self.transientStartTime,
@@ -495,7 +491,6 @@ class TestMCMCTransientSearch(BaseForMCMCSearchTests):
         self._test_plots()
 
     def test_transient_MCMC_t0_tau(self, BtSG=False):
-
         theta = {
             **self.basic_theta,
             "transient_tstart": {
