@@ -16,7 +16,7 @@ def data_parameters():
         "duration": 4 * 1800,
         "detectors": "H1,L1",
         "SFTWindowType": "tukey",
-        "SFTWindowBeta": 0.001,
+        "SFTWindowParam": 0.001,
         "randSeed": 42,
     }
 
@@ -83,7 +83,7 @@ def compare_detector_states_series(dss_0, dss_1):
         ts_0 = dss_0.data[ind].tGPS
         ts_1 = dss_1.data[ind].tGPS
         if ts_0 != ts_1:
-            raise ValueError(f"Timetamps are not consistent: {ts_0} vs. {ts_1}")
+            raise ValueError(f"Timestamps are not consistent: {ts_0} vs. {ts_1}")
 
     return True
 
@@ -103,7 +103,6 @@ def compare_multi_detector_states_series(mdss_0, mdss_1):
 
 
 def test_DetectorStates(data_parameters, writer):
-
     # Test that both input formats of timestamps work consistently
     common_ts = writer.tstart + writer.Tsft * np.arange(writer.duration / writer.Tsft)
     timestamp_options = [
@@ -138,7 +137,6 @@ def test_DetectorStates(data_parameters, writer):
 
 
 def test_SignalToNoiseRatio(writer, multi_detector_states):
-
     params = {
         "h0": 1e-23,
         "cosi": 0,
@@ -185,7 +183,6 @@ def test_SignalToNoiseRatio(writer, multi_detector_states):
 
 
 def test_compute_h0_from_snr2(snr_object):
-
     params = {
         "h0": 1e-23,
         "cosi": 0,
